@@ -24,6 +24,7 @@ class Context:
     ``laboro.context.Context``
   """
   def __init__(self, logger):
+    self.delete_workspace_on_exit = True
     self.logger = logger
     self.store = Store()
     self.history = None
@@ -62,6 +63,7 @@ class Context:
       self.store.clear()
       self._configure_logger(workflow_name, session)
       self._set_workflow_config(workflow_name)
+      self.delete_workspace_on_exit = self.configmgr.get_parameter("workflow", "$.workspace.delete_on_exit")
       self.workspace = Workspace(workspacedir=self.workspacedir,
                                  workflow=workflow_name,
                                  session=session)
@@ -89,7 +91,8 @@ class Context:
       kind: The kind of event that triggered the ``Context`` instance exit.
       value: The `value` of the event that triggered the ``Context`` instance exit.
     """
-    self.workspace.delete()
+    if self.delete_workspace_on_exit:
+      self.workspace.delete()
     self.history.exit(kind, value)
     ErrorHandler().handle_error(name, session, kind, value)
     self.logger.remove_file_handler(session)
