@@ -156,18 +156,19 @@ class Validator:
 
   def _validate_type(self, arg, value, specification):
     arg_type = [aarg["type"] for aarg in specification["args"] if aarg["name"] == arg][0]
-    try:
-      arg_type = getattr(builtins, arg_type)
-      if not isinstance(value, arg_type):
-        msg = {"type": "BadArgTypeError",
-               "message": f"Expected type {arg_type} / received {type(value)} for {arg}."}
+    if arg_type != "any":
+      try:
+        arg_type = getattr(builtins, arg_type)
+        if not isinstance(value, arg_type):
+          msg = {"type": "BadArgTypeError",
+                 "message": f"Expected type {arg_type} / received {type(value)} for {arg}."}
+          logging.critical(f"[{msg['type']}] {msg['message']}")
+          raise LaboroError(f"[{msg['type']}] {msg['message']}")
+      except AttributeError as err:
+        msg = {"type": "UnknownTypeError",
+               "message": f"Unknown type '{arg_type}' for argument {arg}."}
         logging.critical(f"[{msg['type']}] {msg['message']}")
-        raise LaboroError(f"[{msg['type']}] {msg['message']}")
-    except AttributeError as err:
-      msg = {"type": "UnknownTypeError",
-             "message": f"Unknown type '{arg_type}' for argument {arg}."}
-      logging.critical(f"[{msg['type']}] {msg['message']}")
-      raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
+        raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
   def _validate_implied(self, arg, arguments, specification):
     try:
